<?php
// This file is part of Multi-tenancy plugin for Moodle™.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

// phpcs:disable moodle.Files.BoilerplateComment.CommentEndedTooSoon

namespace tool_mutenancy\task;

/**
 * Multi-tenancy cron task.
 *
 * @package    tool_mutenancy
 * @copyright  2025 Petr Skoda
 * @author     Petr Skoda
 * @license    https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class cron extends \core\task\scheduled_task {

    /**
     * Name for this task.
     *
     * @return string
     */
    public function get_name() {
        return get_string('taskcron', 'tool_mutenancy');
    }

    /**
     * Run task for all program cron stuff.
     */
    public function execute() {
        if (!\tool_mutenancy\local\tenancy::is_active()) {
            return;
        }

        $trace = new \text_progress_trace();

        $trace->output('user::sync');
        \tool_mutenancy\local\user::sync(null, null);

        $trace->output('manager::sync');
        \tool_mutenancy\local\manager::sync();

        $trace->finished();
    }
}
